@@ -178,7 +178,7 @@ static int saMifareCSetBlock(uint32_t arg0, uint32_t arg1, uint32_t arg2, uint8_
 a particular sector. also no tracing no dbg */
 static int saMifareChkKeys(uint8_t blockNo, uint8_t keyType, bool clearTrace,
                            uint8_t keyCount, uint8_t *datain, uint64_t *key) {
-    DBGLEVEL = DBG_NONE;
+    g_dbglevel = DBG_NONE;
     iso14443a_setup(FPGA_HF_ISO14443A_READER_LISTEN);
     set_tracing(false);
 
@@ -219,7 +219,7 @@ static int saMifareChkKeys(uint8_t blockNo, uint8_t keyType, bool clearTrace,
  * - tracing is falsed
  */
 static int saMifareECardLoad(uint32_t numofsectors, uint8_t keytype) {
-    DBGLEVEL = DBG_NONE;
+    g_dbglevel = DBG_NONE;
 
     uint8_t numSectors = numofsectors;
     uint8_t keyType = keytype;
