@@ -145,7 +145,7 @@ Initial values if not in flash
         { 29    , 17    , 15    , 40    , 0     , 0     , 15     }, // Leading 0
         { 29    , 17    , 15    , 31    , 47    , 63    , 15     }  // 1 of 4
 */
-t55xx_configurations_t T55xx_Timing  = {
+static t55xx_configurations_t T55xx_Timing  = {
     {
 #ifdef WITH_FLASH
 // PM3RDV4
@@ -338,7 +338,7 @@ void setT55xxConfig(uint8_t arg0, t55xx_configurations_t *c) {
     // write new
     res = Flash_Write(T55XX_CONFIG_OFFSET, buf, T55XX_CONFIG_LEN);
 
-    if (res == T55XX_CONFIG_LEN && DBGLEVEL > 1) {
+    if (res == T55XX_CONFIG_LEN && g_dbglevel > 1) {
         DbpString("T55XX Config save " _GREEN_("success"));
     }
 
@@ -378,7 +378,7 @@ void loadT55xxConfig(void) {
         memcpy((uint8_t *)&T55xx_Timing, buf, T55XX_CONFIG_LEN);
 
     if (isok == T55XX_CONFIG_LEN) {
-        if (DBGLEVEL > 1) DbpString("T55XX Config load success");
+        if (g_dbglevel > 1) DbpString("T55XX Config load success");
     }
 #endif
 }
@@ -1476,17 +1476,9 @@ int lf_em410x_watch(int findone, uint32_t *high, uint64_t *low) {
 
         WDT_HIT();
 
-        errCnt = Em410xDecode(dest, &size, &idx, &hi, &lo);
-        if (errCnt == 1) {
-            if (size == 128) {
-                Dbprintf("EM XL TAG ID: " _GREEN_("%06x%08x%08x") " - ( %05d_%03d_%08d )",
-                         hi,
-                         (uint32_t)(lo >> 32),
-                         (uint32_t)lo,
-                         (uint32_t)(lo & 0xFFFF),
-                         (uint32_t)((lo >> 16LL) & 0xFF),
-                         (uint32_t)(lo & 0xFFFFFF));
-            } else {
+        int type = Em410xDecode(dest, &size, &idx, &hi, &lo);
+        if (type > 0) {
+            if (type & 0x1) {
                 Dbprintf("EM TAG ID: " _GREEN_("%02x%08x") " - ( %05d_%03d_%08d )",
                          (uint32_t)(lo >> 32),
                          (uint32_t)lo,
@@ -1494,7 +1486,38 @@ int lf_em410x_watch(int findone, uint32_t *high, uint64_t *low) {
                          (uint32_t)((lo >> 16LL) & 0xFF),
                          (uint32_t)(lo & 0xFFFFFF));
             }
-
+            if (type & 0x2) {
+                Dbprintf("EM XL TAG ID: " _GREEN_("%06x%08x%08x") " - ( %05d_%03d_%08d )",
+                         hi,
+                         (uint32_t)(lo >> 32),
+                         (uint32_t)lo,
+                         (uint32_t)(lo & 0xFFFF),
+                         (uint32_t)((lo >> 16LL) & 0xFF),
+                         (uint32_t)(lo & 0xFFFFFF));
+            }
+            if (type & 0x4) {
+                uint64_t data = (lo << 20) >> 20;
+                // Convert back to Short ID
+                uint64_t id = ((uint64_t)hi << 16) | (lo >> 48);
+                if ((data & 0xFFFFFFFF) == 0) {
+                    Dbprintf("EM TAG ID: " _GREEN_("%02x%08x") " - ( %05d_%03d_%08d ) Electra "_GREEN_("%i"),
+                             (uint32_t)(id >> 32),
+                             (uint32_t)id,
+                             (uint32_t)(id & 0xFFFF),
+                             (uint32_t)((id >> 16LL) & 0xFF),
+                             (uint32_t)(id & 0xFFFFFF),
+                             (uint32_t)(data >> 32));
+                } else {
+                    Dbprintf("EM TAG ID: " _GREEN_("%02x%08x") " - ( %05d_%03d_%08d ) on 128b frame with data "_GREEN_("%03x%08x"),
+                             (uint32_t)(id >> 32),
+                             (uint32_t)id,
+                             (uint32_t)(id & 0xFFFF),
+                             (uint32_t)((id >> 16LL) & 0xFF),
+                             (uint32_t)(id & 0xFFFFFF),
+                             (uint32_t)(data >> 32),
+                             (uint32_t)data);
+                }
+            }
             if (findone) {
                 *high = hi;
                 *low = lo;
@@ -1833,7 +1856,7 @@ void T55xxDangerousRawTest(uint8_t *data) {
     for (uint8_t i = 0; i < c->bitlen; i++)
         len = T55xx_SetBits(bs, len, c->data[i], 1, sizeof(bs));
 
-    if (DBGLEVEL > 1) {
+    if (g_dbglevel > 1) {
         Dbprintf("LEN %i, TIMING %i", len, c->time);
         for (uint8_t i = 0; i < len; i++) {
             uint8_t sendbits = (bs[BITSTREAM_BYTE(i)] >> BITSTREAM_BIT(i));
@@ -1848,9 +1871,8 @@ void T55xxDangerousRawTest(uint8_t *data) {
     // Trigger T55x7 in mode.
     FpgaWriteConfWord(FPGA_MAJOR_MODE_OFF);
     WaitUS(T55xx_Timing.m[0].start_gap);
-    uint8_t sendbits;
     for (uint8_t i = 0; i < len; i++) {
-        sendbits = (bs[BITSTREAM_BYTE(i)] >> BITSTREAM_BIT(i));
+        uint8_t sendbits = (bs[BITSTREAM_BYTE(i)] >> BITSTREAM_BIT(i));
         T55xxWriteBit(sendbits & 1, 0);
     }
     TurnReadLFOn(c->time);
@@ -1999,6 +2021,12 @@ void T55xxReadBlock(uint8_t page, bool pwd_mode, bool brute_mem, uint8_t block,
     flags                |= (downlink_mode & 3) << 3;
     if (brute_mem) flags |= 0x0100;
 
+    sample_config old_config;
+    sample_config *curr_config = getSamplingConfig();
+    memcpy(&old_config, curr_config, sizeof(sample_config));
+    old_config.verbose = false;
+
+    setDefaultSamplingConfig();
 
     size_t samples = 12000;
 
@@ -2037,6 +2065,9 @@ void T55xxReadBlock(uint8_t page, bool pwd_mode, bool brute_mem, uint8_t block,
         reply_ng(CMD_LF_T55XX_READBL, PM3_SUCCESS, NULL, 0);
         LED_A_OFF();
     }
+
+    // reset back to old / save config
+    setSamplingConfig(&old_config);
 }
 
 
@@ -2071,7 +2102,7 @@ void T55xx_ChkPwds(uint8_t flags) {
     }
     baseline_faulty >>= 5;
 
-    if (DBGLEVEL >= DBG_DEBUG)
+    if (g_dbglevel >= DBG_DEBUG)
         Dbprintf("Baseline " _YELLOW_("%llu"), baseline_faulty);
 
     uint8_t *pwds = BigBuf_get_EM_addr();
@@ -2133,7 +2164,7 @@ void T55xx_ChkPwds(uint8_t flags) {
         int64_t tmp_dist = (baseline_faulty - sum);
         curr = ABS(tmp_dist);
 
-        if (DBGLEVEL >= DBG_DEBUG)
+        if (g_dbglevel >= DBG_DEBUG)
             Dbprintf("%08x has distance " _YELLOW_("%llu"), pwd, curr);
 
         if (curr > prev) {
@@ -2238,7 +2269,7 @@ void CopyHIDtoT55x7(uint32_t hi2, uint32_t hi, uint32_t lo, uint8_t longFMT, boo
     LED_D_ON();
     if (em) {
         Dbprintf("Clone HID Prox to EM4x05 is untested and disabled until verified");
-        if (DBGLEVEL == DBG_DEBUG) {
+        if (g_dbglevel == DBG_DEBUG) {
             Dbprintf("# | data ( EM4x05 )");
             Dbprintf("--+----------------");
             Dbprintf("0 | ", data[0]);
