@@ -28,10 +28,21 @@ Default LF config is set to:
     samples_to_skip = 0
     verbose = YES
     */
-static sample_config config = { 1, 8, 1, LF_DIVISOR_125, 0, 0, 1} ;
+
+static sample_config def_config = {
+    .decimation = 1,
+    .bits_per_sample = 8,
+    .averaging = 1,
+    .divisor = LF_DIVISOR_125,
+    .trigger_threshold = 0,
+    .samples_to_skip = 0,
+    .verbose = false,
+};
+
+static sample_config config = { 1, 8, 1, LF_DIVISOR_125, 0, 0, true} ;
 
 // Holds bit packed struct of samples.
-static BitstreamOut data = {0, 0, 0};
+static BitstreamOut_t data = {0, 0, 0};
 
 // internal struct to keep track of samples gathered
 static sampling_t samples = {0, 0, 0, 0};
@@ -45,9 +56,7 @@ void printLFConfig(void) {
     Dbprintf("  [a] averaging........... %s", (config.averaging) ? "yes" : "no");
     Dbprintf("  [t] trigger threshold... %d", config.trigger_threshold);
     Dbprintf("  [s] samples to skip..... %d ", config.samples_to_skip);
-
-    DbpString(_CYAN_("LF Sampling Stack"));
-    print_stack_usage();
+    DbpString("");
 }
 
 void printSamples(void) {
@@ -59,6 +68,11 @@ void printSamples(void) {
     print_stack_usage();
 }
 
+
+void setDefaultSamplingConfig(void) {
+    setSamplingConfig(&def_config);
+}
+
 /**
  * Called from the USB-handler to set the sampling configuration
  * The sampling config is used for standard reading and sniffing.
@@ -109,7 +123,7 @@ sample_config *getSamplingConfig(void) {
  * @param stream
  * @param bit
  */
-static void pushBit(BitstreamOut *stream, uint8_t bit) {
+static void pushBit(BitstreamOut_t *stream, uint8_t bit) {
     int bytepos = stream->position >> 3; // divide by 8
     int bitpos = stream->position & 7;
     *(stream->buffer + bytepos) &= ~(1 << (7 - bitpos));
@@ -270,7 +284,7 @@ uint32_t DoAcquisition(uint8_t decimation, uint8_t bits_per_sample, bool avg, in
 
     initSampleBuffer(&sample_size);
 
-    if (DBGLEVEL >= DBG_DEBUG) {
+    if (g_dbglevel >= DBG_DEBUG) {
         printSamples();
     }
 
@@ -429,7 +443,7 @@ void doT55x7Acquisition(size_t sample_size) {
 
     uint16_t checker = 0;
 
-    if (DBGLEVEL >= DBG_DEBUG) {
+    if (g_dbglevel >= DBG_DEBUG) {
         Dbprintf("doT55x7Acquisition - after init");
         print_stack_usage();
     }
