@@ -35,7 +35,7 @@ enum MifareAuthSeq {
     masError,
 };
 static enum MifareAuthSeq MifareAuthState;
-static TAuthData AuthData;
+static AuthData_t AuthData;
 
 void ClearAuthData(void) {
     AuthData.uid = 0;
@@ -45,6 +45,9 @@ void ClearAuthData(void) {
     AuthData.ks3 = 0;
 }
 
+
+static int gs_ntag_i2c_state = 0;
+
 /**
  * @brief iso14443A_CRC_check Checks CRC in command or response
  * @param isResponse
@@ -158,7 +161,17 @@ uint8_t iclass_CRC_check(bool isResponse, uint8_t *d, uint8_t n) {
     return check_crc(CRC_ICLASS, d, n);
 }
 
+
 int applyIso14443a(char *exp, size_t size, uint8_t *cmd, uint8_t cmdsize) {
+
+    if ((gs_ntag_i2c_state == 1) && (cmdsize == 6) && (memcmp(cmd + 1, "\x00\x00\x00", 3) == 0)) {
+        snprintf(exp, size, "SECTOR(%d)", cmd[0]);
+        gs_ntag_i2c_state = 0;
+        return 1;
+    }
+
+    gs_ntag_i2c_state = 0;
+
     switch (cmd[0]) {
         case ISO14443A_CMD_WUPA:
             snprintf(exp, size, "WUPA");
@@ -228,9 +241,16 @@ int applyIso14443a(char *exp, size_t size, uint8_t *cmd, uint8_t cmdsize) {
             snprintf(exp, size, "DEC(%d)", cmd[1]);
             break;
         case MIFARE_CMD_RESTORE:
+
             if (cmdsize == 4)
-                snprintf(exp, size, "RESTORE(%d)", cmd[1]);
-            else
+                // cmd0 == 0xC2 and cmd1 == 0xFF
+                // high probability its SELECT SECTOR COMMAND:
+                if (cmd[1] == 0xFF) {
+                    snprintf(exp, size, "SELECT SECTOR");
+                    gs_ntag_i2c_state = 1;
+                } else {
+                    snprintf(exp, size, "RESTORE(%d)", cmd[1]);
+                } else
                 return 0;
             break;
         case MIFARE_CMD_TRANSFER:
@@ -323,6 +343,13 @@ int applyIso14443a(char *exp, size_t size, uint8_t *cmd, uint8_t cmdsize) {
                 snprintf(exp, size, "?");
             break;
         }
+        case NTAG_I2C_FASTWRITE:
+            if (cmdsize == 69)
+                snprintf(exp, size, "FAST WRITE (%d - %d)", cmd[1], cmd[2]);
+            else
+                snprintf(exp, size, "?");
+
+            break;
         default:
             return 0;
     }
@@ -344,10 +371,10 @@ void annotateIclass(char *exp, size_t size, uint8_t *cmd, uint8_t cmdsize, bool
 
     if (isResponse == false)  {
         uint8_t c = cmd[0] & 0x0F;
-        uint8_t parity = 0;
-        for (uint8_t i = 0; i < 7; i++) {
-            parity ^= (cmd[0] >> i) & 1;
-        }
+//        uint8_t parity = 0;
+//        for (uint8_t i = 0; i < 7; i++) {
+//            parity ^= (cmd[0] >> i) & 1;
+//        }
 
         switch (c) {
             case ICLASS_CMD_HALT:
@@ -443,10 +470,10 @@ void annotateIso15693(char *exp, size_t size, uint8_t *cmd, uint8_t cmdsize) {
             case ISO15693_READBLOCK: {
 
                 uint8_t block = 0;
-                if (cmdsize == 13)
-                    block = cmd[10];
-                else if (cmdsize == 5)
+                if (cmdsize == 5)
                     block = cmd[2];
+                else if (cmdsize == 5 + 8) // with UID
+                    block = cmd[2 + 8];
 
                 snprintf(exp, size, "READBLOCK(%d)", block);
                 return;
@@ -455,6 +482,8 @@ void annotateIso15693(char *exp, size_t size, uint8_t *cmd, uint8_t cmdsize) {
                 uint8_t block = 0;
                 if (cmdsize == 9)
                     block = cmd[2];
+                else if (cmdsize == 9 + 8) // with UID
+                    block = cmd[2 + 8];
                 snprintf(exp, size, "WRITEBLOCK(%d)", block);
                 return;
             }
@@ -1551,7 +1580,7 @@ bool DecodeMifareData(uint8_t *cmd, uint8_t cmdsize, uint8_t *parity, bool isRes
     return *mfDataLen > 0;
 }
 
-bool NTParityChk(TAuthData *ad, uint32_t ntx) {
+bool NTParityChk(AuthData_t *ad, uint32_t ntx) {
     if (
         (oddparity8(ntx >> 8 & 0xff) ^ (ntx & 0x01) ^ ((ad->nt_enc_par >> 5) & 0x01) ^ (ad->nt_enc & 0x01)) ||
         (oddparity8(ntx >> 16 & 0xff) ^ (ntx >> 8 & 0x01) ^ ((ad->nt_enc_par >> 6) & 0x01) ^ (ad->nt_enc >> 8 & 0x01)) ||
@@ -1579,7 +1608,7 @@ bool NTParityChk(TAuthData *ad, uint32_t ntx) {
     return true;
 }
 
-bool NestedCheckKey(uint64_t key, TAuthData *ad, uint8_t *cmd, uint8_t cmdsize, uint8_t *parity) {
+bool NestedCheckKey(uint64_t key, AuthData_t *ad, uint8_t *cmd, uint8_t cmdsize, uint8_t *parity) {
     uint8_t buf[32] = {0};
     struct Crypto1State *pcs;
 
@@ -1627,7 +1656,7 @@ bool CheckCrypto1Parity(uint8_t *cmd_enc, uint8_t cmdsize, uint8_t *cmd, uint8_t
 
 // Another implementation of mfkey64 attack,  more "valid" than "probable"
 //
-uint64_t GetCrypto1ProbableKey(TAuthData *ad) {
+uint64_t GetCrypto1ProbableKey(AuthData_t *ad) {
     struct Crypto1State *revstate = lfsr_recovery64(ad->ks2, ad->ks3);
     lfsr_rollback_word(revstate, 0, 0);
     lfsr_rollback_word(revstate, 0, 0);
