@@ -16,7 +16,7 @@
 int CmdLFEM410X(const char *Cmd);
 
 int demodEM410x(bool verbose);
-void printEM410x(uint32_t hi, uint64_t id, bool verbose);
+void printEM410x(uint32_t hi, uint64_t id, bool verbose, int type);
 
 int AskEm410xDecode(bool verbose, uint32_t *hi, uint64_t *lo);
 int AskEm410xDemod(int clk, int invert, int maxErr, size_t maxLen, bool amplify, uint32_t *hi, uint64_t *lo, bool verbose);
