@@ -113,22 +113,22 @@ static bool em4x05_download_samples(void) {
 static int doPreambleSearch(size_t *startIdx) {
 
     // sanity check
-    if (DemodBufferLen < EM_PREAMBLE_LEN) {
-        PrintAndLogEx(DEBUG, "DEBUG: Error - EM4305 demodbuffer too small");
+    if (g_DemodBufferLen < EM_PREAMBLE_LEN) {
+        PrintAndLogEx(DEBUG, "DEBUG: Error - EM4305 DemodBuffer too small");
         return PM3_ESOFT;
     }
 
     // set size to 11 to only test first 3 positions for the preamble
     // do not set it too long else an error preamble followed by 010 could be seen as success.
-    size_t size = (11 > DemodBufferLen) ? DemodBufferLen : 11;
+    size_t size = (11 > g_DemodBufferLen) ? g_DemodBufferLen : 11;
     *startIdx = 0;
 
     // skip first two 0 bits as they might have been missed in the demod
     uint8_t preamble[EM_PREAMBLE_LEN] = {0, 0, 0, 0, 1, 0, 1, 0};
-    if (!preambleSearchEx(DemodBuffer, preamble, EM_PREAMBLE_LEN, &size, startIdx, true)) {
+    if (!preambleSearchEx(g_DemodBuffer, preamble, EM_PREAMBLE_LEN, &size, startIdx, true)) {
 
         uint8_t errpreamble[EM_PREAMBLE_LEN] = {0, 0, 0, 0, 0, 0, 0, 1};
-        if (!preambleSearchEx(DemodBuffer, errpreamble, EM_PREAMBLE_LEN, &size, startIdx, true)) {
+        if (!preambleSearchEx(g_DemodBuffer, errpreamble, EM_PREAMBLE_LEN, &size, startIdx, true)) {
             PrintAndLogEx(DEBUG, "DEBUG: Error - EM4305 preamble not found :: %zu", *startIdx);
             return PM3_ESOFT;
         }
@@ -168,14 +168,14 @@ static bool detectPSK(void) {
     }
 
     // In order to hit the INVERT,  we need to demod here
-    if (DemodBufferLen < 11) {
+    if (g_DemodBufferLen < 11) {
         PrintAndLogEx(INFO, " demod buff len less than PREAMBLE lEN");
     }
 
-    size_t size = (11 > DemodBufferLen) ? DemodBufferLen : 11;
+    size_t size = (11 > g_DemodBufferLen) ? g_DemodBufferLen : 11;
     size_t startIdx = 0;
     uint8_t preamble[EM_PREAMBLE_LEN] = {0, 0, 0, 0, 1, 0, 1, 0};
-    if (!preambleSearchEx(DemodBuffer, preamble, EM_PREAMBLE_LEN, &size, &startIdx, true)) {
+    if (!preambleSearchEx(g_DemodBuffer, preamble, EM_PREAMBLE_LEN, &size, &startIdx, true)) {
 
         //try psk1 inverted
         ans = PSKDemod(0, 1, 6, false);
@@ -184,7 +184,7 @@ static bool detectPSK(void) {
             return false;
         }
 
-        if (!preambleSearchEx(DemodBuffer, preamble, EM_PREAMBLE_LEN, &size, &startIdx, true)) {
+        if (!preambleSearchEx(g_DemodBuffer, preamble, EM_PREAMBLE_LEN, &size, &startIdx, true)) {
             PrintAndLogEx(DEBUG, "DEBUG: Error - EM: PSK1 inverted Demod failed 2");
             return false;
         }
@@ -237,19 +237,19 @@ static int em4x05_setdemod_buffer(uint32_t *word, size_t idx) {
 
     //test for even parity bits.
     uint8_t parity[45] = {0};
-    memcpy(parity, DemodBuffer, 45);
-    if (!em4x05_col_parity_test(DemodBuffer + idx + EM_PREAMBLE_LEN, 45, 5, 9, 0)) {
+    memcpy(parity, g_DemodBuffer, 45);
+    if (!em4x05_col_parity_test(g_DemodBuffer + idx + EM_PREAMBLE_LEN, 45, 5, 9, 0)) {
         PrintAndLogEx(DEBUG, "DEBUG: Error - End Parity check failed");
         return PM3_ESOFT;
     }
 
     // test for even parity bits and remove them. (leave out the end row of parities so 36 bits)
-    if (!removeParity(DemodBuffer, idx + EM_PREAMBLE_LEN, 9, 0, 36)) {
+    if (!removeParity(g_DemodBuffer, idx + EM_PREAMBLE_LEN, 9, 0, 36)) {
         PrintAndLogEx(DEBUG, "DEBUG: Error - EM, failed removing parity");
         return PM3_ESOFT;
     }
-    setDemodBuff(DemodBuffer, 32, 0);
-    *word = bytebits_to_byteLSBF(DemodBuffer, 32);
+    setDemodBuff(g_DemodBuffer, 32, 0);
+    *word = bytebits_to_byteLSBF(g_DemodBuffer, 32);
     return PM3_SUCCESS;
 }
 
@@ -299,7 +299,7 @@ static int em4x05_demod_resp(uint32_t *word, bool onlyPreamble) {
             if (res == PM3_EFAILED)
                 found_err = true;
 
-            psk1TOpsk2(DemodBuffer, DemodBufferLen);
+            psk1TOpsk2(g_DemodBuffer, g_DemodBufferLen);
             res = doPreambleSearch(&idx);
             if (res == PM3_SUCCESS)
                 break;
@@ -348,13 +348,13 @@ int em4x05_clone_tag(uint32_t *blockdata, uint8_t numblocks, uint32_t pwd, bool
         return PM3_EINVARG;
 
     // fast push mode
-    conn.block_after_ACK = true;
+    g_conn.block_after_ACK = true;
     int res = 0;
     for (int8_t i = 0; i < numblocks; i++) {
 
         // Disable fast mode on last packet
         if (i == numblocks - 1) {
-            conn.block_after_ACK = false;
+            g_conn.block_after_ACK = false;
         }
 
         if (i != 0) {
@@ -539,10 +539,8 @@ int CmdEM4x05Dump(const char *Cmd) {
     uint32_t data[16];
 
     int success = PM3_SUCCESS;
-    int status, status14, status15;
     uint32_t lock_bits = 0x00; // no blocks locked
     bool gotLockBits = false;
-    bool lockInPW2 = false;
     uint32_t word = 0;
 
     const char *info[] = {"Info/User", "UID", "Password", "User", "Config", "User", "User", "User", "User", "User", "User", "User", "User", "User", "Lock", "Lock"};
@@ -555,7 +553,7 @@ int CmdEM4x05Dump(const char *Cmd) {
 
     if (usePwd) {
         // Test first if the password is correct
-        status = em4x05_login_ext(pwd);
+        int status = em4x05_login_ext(pwd);
         if (status == PM3_SUCCESS) {
             PrintAndLogEx(INFO, "password is " _GREEN_("correct"));
         } else if (status == PM3_EFAILED) {
@@ -572,11 +570,10 @@ int CmdEM4x05Dump(const char *Cmd) {
     PrintAndLogEx(INFO, "-----+----------+-------+---+-----");
 
     if (card_type == EM_4205 || card_type == EM_4305 || card_type == EM_UNKNOWN) {
-
-
+        bool lockInPW2 = false;
         // To flag any blocks locked we need to read blocks 14 and 15 first
         // dont swap endian until we get block lock flags.
-        status14 = em4x05_read_word_ext(EM4305_PROT1_BLOCK, pwd, usePwd, &word);
+        int status14 = em4x05_read_word_ext(EM4305_PROT1_BLOCK, pwd, usePwd, &word);
         if (status14 == PM3_SUCCESS) {
             if ((word & 0x00008000) != 0x00) {
                 lock_bits = word;
@@ -586,7 +583,7 @@ int CmdEM4x05Dump(const char *Cmd) {
         } else {
             success = PM3_ESOFT; // If any error ensure fail is set so not to save invalid data
         }
-        status15 = em4x05_read_word_ext(EM4305_PROT2_BLOCK, pwd, usePwd, &word);
+        int status15 = em4x05_read_word_ext(EM4305_PROT2_BLOCK, pwd, usePwd, &word);
         if (status15 == PM3_SUCCESS) {
             if ((word & 0x00008000) != 0x00) { // assume block 15 is the current lock block
                 lock_bits = word;
@@ -612,7 +609,7 @@ int CmdEM4x05Dump(const char *Cmd) {
                 }
             } else {
                 // success &= em4x05_read_word_ext(addr, pwd, usePwd, &word);
-                status = em4x05_read_word_ext(addr, pwd, usePwd, &word); // Get status for single read
+                int status = em4x05_read_word_ext(addr, pwd, usePwd, &word); // Get status for single read
                 if (status != PM3_SUCCESS)
                     success = PM3_ESOFT; // If any error ensure fail is set so not to save invalid data
                 data[addr] = BSWAP_32(word);
@@ -647,7 +644,7 @@ int CmdEM4x05Dump(const char *Cmd) {
 
         // To flag any blocks locked we need to read block 3 first
         // dont swap endian until we get block lock flags.
-        status14 = em4x05_read_word_ext(EM4469_PROT_BLOCK, pwd, usePwd, &word);
+        int status14 = em4x05_read_word_ext(EM4469_PROT_BLOCK, pwd, usePwd, &word);
         if (status14 == PM3_SUCCESS) {
             lock_bits = word;
             gotLockBits = true;
@@ -656,10 +653,8 @@ int CmdEM4x05Dump(const char *Cmd) {
             success = PM3_ESOFT; // If any error ensure fail is set so not to save invalid data
         }
 
-        uint32_t lockbit;
-
         for (; addr < 16; addr++) {
-            lockbit = (lock_bits >> (addr * 2)) & 3;
+            uint32_t lockbit = (lock_bits >> (addr * 2)) & 3;
             if (addr == 2) {
                 if (usePwd) {
                     data[addr] = BSWAP_32(pwd);
@@ -671,7 +666,7 @@ int CmdEM4x05Dump(const char *Cmd) {
                 }
             } else {
 
-                status = em4x05_read_word_ext(addr, pwd, usePwd, &word);
+                int status = em4x05_read_word_ext(addr, pwd, usePwd, &word);
                 if (status != PM3_SUCCESS) {
                     success = PM3_ESOFT; // If any error ensure fail is set so not to save invalid data
                 }
@@ -1390,7 +1385,7 @@ int CmdEM4x05Chk(const char *Cmd) {
 
         for (uint32_t c = 0; c < keycount; ++c) {
 
-            if (!session.pm3_present) {
+            if (!g_session.pm3_present) {
                 PrintAndLogEx(WARNING, "device offline\n");
                 free(keyBlock);
                 return PM3_ENODATA;
@@ -1569,7 +1564,7 @@ int CmdEM4x05Unlock(const char *Cmd) {
         return PM3_EINVARG;
     }
 
-    if (session.pm3_present == false) {
+    if (g_session.pm3_present == false) {
         PrintAndLogEx(WARNING, "device offline\n");
         return PM3_ENODATA;
     }
@@ -1970,9 +1965,6 @@ uint32_t static em4x05_Sniff_GetBlock(char *bits, bool fwd) {
 
 int CmdEM4x05Sniff(const char *Cmd) {
 
-    bool pwd = false, fwd = false;
-    bool haveData, sampleData = true;
-
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "lf em 4x05 sniff",
                   "Sniff EM4x05 commands sent from a programmer",
@@ -1988,8 +1980,8 @@ int CmdEM4x05Sniff(const char *Cmd) {
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, true);
-    sampleData = (arg_get_lit(ctx, 1) == false);
-    fwd = arg_get_lit(ctx, 2);
+    bool sampleData = (arg_get_lit(ctx, 1) == false);
+    bool fwd = arg_get_lit(ctx, 2);
     CLIParserFree(ctx);
 
     char cmdText[100];
@@ -1999,9 +1991,7 @@ int CmdEM4x05Sniff(const char *Cmd) {
     int i, bitidx;
     int ZeroWidth;    // 32-42 "1" is 32
     int CycleWidth;
-    size_t idx = 0, pulseSamples, pktOffset;
-    uint32_t tmpValue;
-    bool eop = false;
+    size_t pulseSamples;
 
     // setup and sample data from Proxmark
     // if not directed to existing sample/graphbuffer
@@ -2019,20 +2009,21 @@ int CmdEM4x05Sniff(const char *Cmd) {
     PrintAndLogEx(SUCCESS, "offset | Command     |   Data   | blk | raw");
     PrintAndLogEx(SUCCESS, "-------+-------------+----------+-----+------------------------------------------------------------");
 
-    idx = 0;
+    size_t idx = 0;
     // loop though sample buffer
-    while (idx < GraphTraceLen) {
-        eop = false;
-        haveData = false;
-        pwd = false;
+    while (idx < g_GraphTraceLen) {
+        bool eop = false;
+        bool haveData = false;
+        bool pwd = false;
+        uint32_t tmpValue;
 
-        idx = em4x05_Sniff_GetNextBitStart(idx, GraphTraceLen, GraphBuffer, &pulseSamples);
-        pktOffset = idx;
+        idx = em4x05_Sniff_GetNextBitStart(idx, g_GraphTraceLen, g_GraphBuffer, &pulseSamples);
+        size_t pktOffset = idx;
         if (pulseSamples >= 10)  { // Should be 18 so a bit less to allow for processing
 
             // Use first bit to get "0" bit samples as a reference
             ZeroWidth = idx;
-            idx = em4x05_Sniff_GetNextBitStart(idx, GraphTraceLen, GraphBuffer, &pulseSamples);
+            idx = em4x05_Sniff_GetNextBitStart(idx, g_GraphTraceLen, g_GraphBuffer, &pulseSamples);
             ZeroWidth = idx - ZeroWidth;
 
             if (ZeroWidth <= 50) {
@@ -2040,9 +2031,9 @@ int CmdEM4x05Sniff(const char *Cmd) {
                 memset(bits, 0x00, sizeof(bits));
                 bitidx = 0;
 
-                while ((idx < GraphTraceLen) && !eop) {
+                while ((idx < g_GraphTraceLen) && !eop) {
                     CycleWidth = idx;
-                    idx = em4x05_Sniff_GetNextBitStart(idx, GraphTraceLen, GraphBuffer, &pulseSamples);
+                    idx = em4x05_Sniff_GetNextBitStart(idx, g_GraphTraceLen, g_GraphBuffer, &pulseSamples);
 
                     CycleWidth = idx - CycleWidth;
                     if ((CycleWidth > 300) || (CycleWidth < (ZeroWidth - 5))) { // to long or too short
