@@ -18,16 +18,16 @@
 #include "graph.h"
 #include "cliparser.h"
 #include "commonutil.h"
-#include "ui.h"         // PrintAndLog
+#include "ui.h"           // PrintAndLog
 #include "proxgui.h"
-#include "lfdemod.h"    // parityTest, bitbytes_to_byte
+#include "lfdemod.h"      // parityTest, bitbytes_to_byte
 #include "cmddata.h"
-#include "cmdlf.h"      // lf_read
-#include "protocols.h"  // t55 defines
-#include "cmdlft55xx.h" // verifywrite
+#include "cmdlf.h"        // lf_read
+#include "protocols.h"    // t55 defines
+#include "cmdlft55xx.h"   // verifywrite
 #include "cliparser.h"
 #include "cmdlfem4x05.h"  // EM defines
-
+#include "parity.h"       // parity
 #define INDALA_ARR_LEN 64
 
 static int CmdHelp(const char *Cmd);
@@ -124,8 +124,8 @@ int demodIndalaEx(int clk, int invert, int maxErr, bool verbose) {
     }
 
     uint8_t inv = 0;
-    size_t size = DemodBufferLen;
-    int idx = detectIndala(DemodBuffer, &size, &inv);
+    size_t size = g_DemodBufferLen;
+    int idx = detectIndala(g_DemodBuffer, &size, &inv);
     if (idx < 0) {
         if (idx == -1)
             PrintAndLogEx(DEBUG, "DEBUG: Error - Indala: not enough samples");
@@ -139,87 +139,93 @@ int demodIndalaEx(int clk, int invert, int maxErr, bool verbose) {
             PrintAndLogEx(DEBUG, "DEBUG: Error - Indala: error demoding psk idx: %d", idx);
         return PM3_ESOFT;
     }
-    setDemodBuff(DemodBuffer, size, idx);
+    setDemodBuff(g_DemodBuffer, size, idx);
     setClockGrid(g_DemodClock, g_DemodStartIdx + (idx * g_DemodClock));
 
     //convert UID to HEX
-    uint32_t uid1 = bytebits_to_byte(DemodBuffer, 32);
-    uint32_t uid2 = bytebits_to_byte(DemodBuffer + 32, 32);
+    uint32_t uid1 = bytebits_to_byte(g_DemodBuffer, 32);
+    uint32_t uid2 = bytebits_to_byte(g_DemodBuffer + 32, 32);
     // To be checked, what's this internal ID ?
     // foo is only used for 64b ids and in that case uid1 must be only preamble, plus the following code is wrong as x<<32 & 0x1FFFFFFF is always zero
     //uint64_t foo = (((uint64_t)uid1 << 32) & 0x1FFFFFFF) | (uid2 & 0x7FFFFFFF);
     uint64_t foo = uid2 & 0x7FFFFFFF;
 
-    if (DemodBufferLen == 64) {
-        PrintAndLogEx(SUCCESS, "Indala (len %zu)  Raw: " _GREEN_("%x%08x"), DemodBufferLen, uid1, uid2);
+    if (g_DemodBufferLen == 64) {
+        PrintAndLogEx(SUCCESS, "Indala (len %zu)  Raw: " _GREEN_("%x%08x"), g_DemodBufferLen, uid1, uid2);
 
         uint16_t p1  = 0;
-        p1 |= DemodBuffer[32 + 3] << 8;
-        p1 |= DemodBuffer[32 + 6] << 5;
-        p1 |= DemodBuffer[32 + 8] << 4;
-        p1 |= DemodBuffer[32 + 9] << 3;
-        p1 |= DemodBuffer[32 + 11] << 1;
-        p1 |= DemodBuffer[32 + 16] << 6;
-        p1 |= DemodBuffer[32 + 19] << 7;
-        p1 |= DemodBuffer[32 + 20] << 10;
-        p1 |= DemodBuffer[32 + 21] << 2;
-        p1 |= DemodBuffer[32 + 22] << 0;
-        p1 |= DemodBuffer[32 + 24] << 9;
+        p1 |= g_DemodBuffer[32 + 3] << 8;
+        p1 |= g_DemodBuffer[32 + 6] << 5;
+        p1 |= g_DemodBuffer[32 + 8] << 4;
+        p1 |= g_DemodBuffer[32 + 9] << 3;
+        p1 |= g_DemodBuffer[32 + 11] << 1;
+        p1 |= g_DemodBuffer[32 + 16] << 6;
+        p1 |= g_DemodBuffer[32 + 19] << 7;
+        p1 |= g_DemodBuffer[32 + 20] << 10;
+        p1 |= g_DemodBuffer[32 + 21] << 2;
+        p1 |= g_DemodBuffer[32 + 22] << 0;
+        p1 |= g_DemodBuffer[32 + 24] << 9;
 
         uint8_t fc = 0;
-        fc |= DemodBuffer[57] << 7; // b8
-        fc |= DemodBuffer[49] << 6; // b7
-        fc |= DemodBuffer[44] << 5; // b6
-        fc |= DemodBuffer[47] << 4; // b5
-        fc |= DemodBuffer[48] << 3; // b4
-        fc |= DemodBuffer[53] << 2; // b3
-        fc |= DemodBuffer[39] << 1; // b2
-        fc |= DemodBuffer[58] << 0; // b1
+        fc |= g_DemodBuffer[57] << 7; // b8
+        fc |= g_DemodBuffer[49] << 6; // b7
+        fc |= g_DemodBuffer[44] << 5; // b6
+        fc |= g_DemodBuffer[47] << 4; // b5
+        fc |= g_DemodBuffer[48] << 3; // b4
+        fc |= g_DemodBuffer[53] << 2; // b3
+        fc |= g_DemodBuffer[39] << 1; // b2
+        fc |= g_DemodBuffer[58] << 0; // b1
 
         uint16_t csn = 0;
-        csn |= DemodBuffer[42] << 15; // b16
-        csn |= DemodBuffer[45] << 14; // b15
-        csn |= DemodBuffer[43] << 13; // b14
-        csn |= DemodBuffer[40] << 12; // b13
-        csn |= DemodBuffer[52] << 11; // b12
-        csn |= DemodBuffer[36] << 10; // b11
-        csn |= DemodBuffer[35] << 9; // b10
-        csn |= DemodBuffer[51] << 8; // b9
-        csn |= DemodBuffer[46] << 7; // b8
-        csn |= DemodBuffer[33] << 6; // b7
-        csn |= DemodBuffer[37] << 5; // b6
-        csn |= DemodBuffer[54] << 4; // b5
-        csn |= DemodBuffer[56] << 3; // b4
-        csn |= DemodBuffer[59] << 2; // b3
-        csn |= DemodBuffer[50] << 1; // b2
-        csn |= DemodBuffer[41] << 0; // b1
+        csn |= g_DemodBuffer[42] << 15; // b16
+        csn |= g_DemodBuffer[45] << 14; // b15
+        csn |= g_DemodBuffer[43] << 13; // b14
+        csn |= g_DemodBuffer[40] << 12; // b13
+        csn |= g_DemodBuffer[52] << 11; // b12
+        csn |= g_DemodBuffer[36] << 10; // b11
+        csn |= g_DemodBuffer[35] << 9; // b10
+        csn |= g_DemodBuffer[51] << 8; // b9
+        csn |= g_DemodBuffer[46] << 7; // b8
+        csn |= g_DemodBuffer[33] << 6; // b7
+        csn |= g_DemodBuffer[37] << 5; // b6
+        csn |= g_DemodBuffer[54] << 4; // b5
+        csn |= g_DemodBuffer[56] << 3; // b4
+        csn |= g_DemodBuffer[59] << 2; // b3
+        csn |= g_DemodBuffer[50] << 1; // b2
+        csn |= g_DemodBuffer[41] << 0; // b1
+
+        uint8_t parity = 0;
+        parity |= g_DemodBuffer[34] << 1; // b2
+        parity |= g_DemodBuffer[38] << 0; // b1
 
         uint8_t checksum = 0;
-        checksum |= DemodBuffer[62] << 1; // b2
-        checksum |= DemodBuffer[63] << 0; // b1
+        checksum |= g_DemodBuffer[62] << 1; // b2
+        checksum |= g_DemodBuffer[63] << 0; // b1
 
-        PrintAndLogEx(SUCCESS, "Fmt " _GREEN_("26") " FC: " _GREEN_("%u") " Card: " _GREEN_("%u") " checksum: " _GREEN_("%1d%1d")
+        PrintAndLogEx(SUCCESS, "Fmt " _GREEN_("26") " FC: " _GREEN_("%u") " Card: " _GREEN_("%u") " Parity: " _GREEN_("%1d%1d")
                       , fc
                       , csn
-                      , checksum >> 1 & 0x01
-                      , checksum & 0x01
+                      , parity >> 1 & 0x01
+                      , parity & 0x01
                      );
+        PrintAndLogEx(DEBUG, "two bit checksum... " _GREEN_("%1d%1d"), checksum >> 1 & 0x01, checksum & 0x01);
 
         PrintAndLogEx(SUCCESS, "Possible de-scramble patterns");
+        // This doesn't seem to line up with the hot-stamp numbers on any HID cards I have seen, but, leaving it alone since I do not know how those work. -MS
         PrintAndLogEx(SUCCESS, "    Printed     | __%04d__ [0x%X]", p1, p1);
         PrintAndLogEx(SUCCESS, "    Internal ID | %" PRIu64, foo);
-        decodeHeden2L(DemodBuffer);
+        decodeHeden2L(g_DemodBuffer);
 
     } else {
-        uint32_t uid3 = bytebits_to_byte(DemodBuffer + 64, 32);
-        uint32_t uid4 = bytebits_to_byte(DemodBuffer + 96, 32);
-        uint32_t uid5 = bytebits_to_byte(DemodBuffer + 128, 32);
-        uint32_t uid6 = bytebits_to_byte(DemodBuffer + 160, 32);
-        uint32_t uid7 = bytebits_to_byte(DemodBuffer + 192, 32);
+        uint32_t uid3 = bytebits_to_byte(g_DemodBuffer + 64, 32);
+        uint32_t uid4 = bytebits_to_byte(g_DemodBuffer + 96, 32);
+        uint32_t uid5 = bytebits_to_byte(g_DemodBuffer + 128, 32);
+        uint32_t uid6 = bytebits_to_byte(g_DemodBuffer + 160, 32);
+        uint32_t uid7 = bytebits_to_byte(g_DemodBuffer + 192, 32);
         PrintAndLogEx(
             SUCCESS
             , "Indala (len %zu)  Raw: " _GREEN_("%x%08x%08x%08x%08x%08x%08x")
-            , DemodBufferLen
+            , g_DemodBufferLen
             , uid1
             , uid2
             , uid3
@@ -231,7 +237,7 @@ int demodIndalaEx(int clk, int invert, int maxErr, bool verbose) {
     }
 
     if (g_debugMode) {
-        PrintAndLogEx(DEBUG, "DEBUG: Indala - printing demodbuffer");
+        PrintAndLogEx(DEBUG, "DEBUG: Indala - printing DemodBuffer");
         printDemodBuff(0, false, false, false);
     }
     return PM3_SUCCESS;
@@ -245,11 +251,11 @@ static int CmdIndalaDemod(const char *Cmd) {
 
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "lf indala demod",
-                  "Tries to psk demodulate the graphbuffer as Indala",
+                  "Tries to PSK demodulate the graphbuffer as Indala",
                   "lf indala demod\n"
-                  "lf indala demod --clock 32      -> demod a Indala tag from GraphBuffer using a clock of RF/32\n"
-                  "lf indala demod --clock 32 -i    -> demod a Indala tag from GraphBuffer using a clock of RF/32 and inverting data\n"
-                  "lf indala demod --clock 64 -i --maxerror 0  -> demod a Indala tag from GraphBuffer using a clock of RF/64, inverting data and allowing 0 demod errors"
+                  "lf indala demod --clock 32      -> demod a Indala tag from the GraphBuffer using a clock of RF/32\n"
+                  "lf indala demod --clock 32 -i    -> demod a Indala tag from the GraphBuffer using a clock of RF/32 and inverting data\n"
+                  "lf indala demod --clock 64 -i --maxerror 0  -> demod a Indala tag from the GraphBuffer using a clock of RF/64, inverting data and allowing 0 demod errors"
                  );
 
     void *argtable[] = {
@@ -276,11 +282,11 @@ static int CmdIndalaDemodAlt(const char *Cmd) {
 
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "lf indala altdemod",
-                  "Tries to psk demodulate the graphbuffer as Indala\n"
+                  "Tries to PSK demodulate the graphbuffer as Indala\n"
                   "This is uses a alternative way to demodulate and was used from the beginning in the Pm3 client.\n"
                   "It's now considered obsolete but remains because it has sometimes its advantages.",
                   "lf indala altdemod\n"
-                  "lf indala altdemod --long     -> demod a Indala tag from GraphBuffer as 224 bit long format"
+                  "lf indala altdemod --long     -> demod a Indala tag from the GraphBuffer as 224 bit long format"
                  );
 
     void *argtable[] = {
@@ -297,7 +303,7 @@ static int CmdIndalaDemodAlt(const char *Cmd) {
     int count = 0;
     int i, j;
 
-    // worst case with GraphTraceLen=40000 is < 4096
+    // worst case with g_GraphTraceLen=40000 is < 4096
     // under normal conditions it's < 2048
     uint8_t data[MAX_GRAPH_TRACE_LEN] = {0};
     size_t datasize = getFromGraphBuf(data);
@@ -308,9 +314,9 @@ static int CmdIndalaDemodAlt(const char *Cmd) {
 
     //clear clock grid and demod plot
     setClockGrid(0, 0);
-    DemodBufferLen = 0;
+    g_DemodBufferLen = 0;
 
-    // PrintAndLogEx(NORMAL, "Expecting a bit less than %d raw bits", GraphTraceLen / 32);
+    // PrintAndLogEx(NORMAL, "Expecting a bit less than %d raw bits", g_GraphTraceLen / 32);
     // loop through raw signal - since we know it is psk1 rf/32 fc/2 skip every other value (+=2)
     for (i = 0; i < datasize - 1; i += 2) {
         count += 1;
@@ -344,8 +350,8 @@ static int CmdIndalaDemodAlt(const char *Cmd) {
     }
 
     if (rawbit > 0) {
-        PrintAndLogEx(INFO, "Recovered %d raw bits, expected: %zu", rawbit, GraphTraceLen / 32);
-        PrintAndLogEx(INFO, "worst metric (0=best..7=worst): %d at pos %d", worst, worstPos);
+        PrintAndLogEx(INFO, "Recovered %d raw bits, expected: %zu", rawbit, g_GraphTraceLen / 32);
+        PrintAndLogEx(INFO, "Worst metric (0=best..7=worst): %d at pos %d", worst, worstPos);
     } else {
         return PM3_ESOFT;
     }
@@ -375,7 +381,7 @@ static int CmdIndalaDemodAlt(const char *Cmd) {
     }
 
     if (start == rawbit - uidlen + 1) {
-        PrintAndLogEx(FAILED, "nothing to wait for");
+        PrintAndLogEx(FAILED, "Nothing to wait for");
         return PM3_ESOFT;
     }
 
@@ -470,7 +476,7 @@ static int CmdIndalaDemodAlt(const char *Cmd) {
     // Remodulating for tag cloning
     // HACK: 2015-01-04 this will have an impact on our new way of seening lf commands (demod)
     // since this changes graphbuffer data.
-    GraphTraceLen = 32 * uidlen;
+    g_GraphTraceLen = 32 * uidlen;
     i = 0;
     int phase;
     for (bit = 0; bit < uidlen; bit++) {
@@ -480,7 +486,7 @@ static int CmdIndalaDemodAlt(const char *Cmd) {
             phase = 1;
         }
         for (j = 0; j < 32; j++) {
-            GraphBuffer[i++] = phase;
+            g_GraphBuffer[i++] = phase;
             phase = !phase;
         }
     }
@@ -527,7 +533,7 @@ static int CmdIndalaSim(const char *Cmd) {
 
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "lf indala sim",
-                  "Enables simulation of Indala card with specified facility-code and card number.\n"
+                  "Enables simulation of Indala card with specified facility code and card number.\n"
                   "Simulation runs until the button is pressed or another USB command is issued.",
                   "lf indala sim --heden 888\n"
                   "lf indala sim --raw a0000000a0002021\n"
@@ -623,21 +629,23 @@ static int CmdIndalaClone(const char *Cmd) {
 
     CLIParserContext *ctx;
     CLIParserInit(&ctx, "lf indala clone",
-                  "clone Indala UID to T55x7 or Q5/T5555 tag\n"
+                  "clone Indala UID to T55x7 or Q5/T5555 tag using different known formats\n"
                   _RED_("\nWarning, encoding with FC/CN doesn't always work"),
-                  "lf indala clone --heden 888\n"
-                  "lf indala clone --fc 123 --cn 1337\n"
+                  "lf indala clone --heden 888                --> use Heden 2L format\n"
+                  "lf indala clone --fc 123 --cn 1337         --> use standard 26b format\n"
+                  "lf indala clone --fc 123 --cn 1337 --4041x --> use 4041x format\n"
                   "lf indala clone -r a0000000a0002021\n"
                   "lf indala clone -r 80000001b23523a6c2e31eba3cbee4afb3c6ad1fcf649393928c14e5");
 
     void *argtable[] = {
         arg_param_begin,
         arg_strx0("r", "raw", "<hex>", "raw bytes"),
-        arg_int0(NULL, "heden", "<decimal>", "Cardnumber for Heden 2L format"),
-        arg_int0(NULL, "fc", "<decimal>", "Facility Code (26 bit H10301 format)"),
-        arg_int0(NULL, "cn", "<decimal>", "Cardnumber (26 bit H10301 format)"),
-        arg_lit0(NULL, "q5", "optional - specify writing to Q5/T5555 tag"),
-        arg_lit0(NULL, "em", "optional - specify writing to EM4305/4469 tag"),
+        arg_int0(NULL, "heden", "<decimal>", "Card number for Heden 2L format"),
+        arg_int0(NULL, "fc", "<decimal>", "Facility code (26 bit H10301 format)"),
+        arg_int0(NULL, "cn", "<decimal>", "Card number (26 bit H10301 format)"),
+        arg_lit0(NULL, "q5", "Optional - specify writing to Q5/T5555 tag"),
+        arg_lit0(NULL, "em", "Optional - specify writing to EM4305/4469 tag"),
+        arg_lit0(NULL, "4041x", "Optional - specify Indala 4041X format, must use with fc and cn"),
         arg_param_end
     };
     CLIExecWithReturn(ctx, Cmd, argtable, false);
@@ -649,6 +657,7 @@ static int CmdIndalaClone(const char *Cmd) {
     bool is_long_uid = (raw_len == 28);
     bool q5 = arg_get_lit(ctx, 5);
     bool em = arg_get_lit(ctx, 6);
+    bool fmt4041x = arg_get_lit(ctx, 7);
 
     bool got_cn = false, got_26 = false;
     if (is_long_uid == false) {
@@ -669,6 +678,11 @@ static int CmdIndalaClone(const char *Cmd) {
         return PM3_EINVARG;
     }
 
+    if ((!got_26) && fmt4041x) {
+        PrintAndLogEx(FAILED, "You must specify a facility code and card number when using 4041X format");
+        return PM3_EINVARG;
+    }
+
     uint8_t max = 0;
     uint32_t blocks[8] = {0};
     char cardtype[16] = {"T55x7"};
@@ -697,12 +711,11 @@ static int CmdIndalaClone(const char *Cmd) {
 
         // 224 BIT UID
         // config for Indala (RF/32;PSK2 with RF/2;Maxblock=7)
-        PrintAndLogEx(INFO, "Preparing to clone Indala 224bit to " _YELLOW_("%s") " raw " _GREEN_("%s")
+        PrintAndLogEx(INFO, "Preparing to clone Indala 224 bit to " _YELLOW_("%s") " raw " _GREEN_("%s")
                       , cardtype
                       , sprint_hex_inrow(raw, raw_len)
                      );
 
-
     } else {
         // 64 BIT UID
         if (got_cn) {
@@ -710,7 +723,7 @@ static int CmdIndalaClone(const char *Cmd) {
             raw_len = 8;
         } else if (got_26) {
 
-            PrintAndLogEx(INFO, "Using Indala 26b FC " _GREEN_("%u") " CN " _GREEN_("%u"), fc, cn);
+            PrintAndLogEx(INFO, "Using Indala 64 bit, FC " _GREEN_("%u") " CN " _GREEN_("%u"), fc, cn);
 
             // Used with the 26bit FC/CSN
             uint8_t *bits = calloc(INDALA_ARR_LEN, sizeof(uint8_t));
@@ -719,10 +732,18 @@ static int CmdIndalaClone(const char *Cmd) {
                 return PM3_EMALLOC;
             }
 
-            if (getIndalaBits(fc, cn, bits) != PM3_SUCCESS) {
+            // Bitstream generation, format select
+            int indalaReturn = PM3_ESOFT;
+            if (fmt4041x) {
+                indalaReturn = getIndalaBits4041x(fc, cn, bits);
+            } else {
+                indalaReturn = getIndalaBits(fc, cn, bits);
+            }
+
+            if (indalaReturn != PM3_SUCCESS) {
                 PrintAndLogEx(ERR, "Error with tag bitstream generation.");
                 free(bits);
-                return PM3_ESOFT;
+                return indalaReturn;
             }
 
             raw[0] = bytebits_to_byte(bits, 8);
@@ -755,7 +776,7 @@ static int CmdIndalaClone(const char *Cmd) {
         max = 3;
 
         // config for Indala 64 format (RF/32;PSK1 with RF/2;Maxblock=2)
-        PrintAndLogEx(INFO, "Preparing to clone Indala 64bit to " _YELLOW_("%s") " raw " _GREEN_("%s")
+        PrintAndLogEx(INFO, "Preparing to clone Indala 64 bit to " _YELLOW_("%s") " raw " _GREEN_("%s")
                       , cardtype
                       , sprint_hex_inrow(raw, raw_len)
                      );
@@ -775,12 +796,12 @@ static int CmdIndalaClone(const char *Cmd) {
 }
 
 static command_t CommandTable[] = {
-    {"help",     CmdHelp,            AlwaysAvailable, "this help"},
-    {"demod",    CmdIndalaDemod,     AlwaysAvailable, "demodulate an Indala tag (PSK1) from GraphBuffer"},
-    {"altdemod", CmdIndalaDemodAlt,  AlwaysAvailable, "alternative method to demodulate samples for Indala 64 bit UID (option '224' for 224 bit)"},
-    {"reader",   CmdIndalaReader,    IfPm3Lf,         "read an Indala tag from the antenna"},
-    {"clone",    CmdIndalaClone,     IfPm3Lf,         "clone Indala tag to T55x7 or Q5/T5555"},
-    {"sim",      CmdIndalaSim,       IfPm3Lf,         "simulate Indala tag"},
+    {"help",     CmdHelp,            AlwaysAvailable, "This help"},
+    {"demod",    CmdIndalaDemod,     AlwaysAvailable, "Demodulate an Indala tag (PSK1) from the GraphBuffer"},
+    {"altdemod", CmdIndalaDemodAlt,  AlwaysAvailable, "Alternative method to demodulate samples for Indala 64 bit UID (option '224' for 224 bit)"},
+    {"reader",   CmdIndalaReader,    IfPm3Lf,         "Read an Indala tag from the antenna"},
+    {"clone",    CmdIndalaClone,     IfPm3Lf,         "Clone Indala tag to T55x7 or Q5/T5555"},
+    {"sim",      CmdIndalaSim,       IfPm3Lf,         "Simulate Indala tag"},
     {NULL, NULL, NULL, NULL}
 };
 
@@ -860,6 +881,58 @@ int getIndalaBits(uint8_t fc, uint16_t cn, uint8_t *bits) {
     return PM3_SUCCESS;
 }
 
+/*
+    Permutation table for this format, lower 4 bytes of card data.
+
+    0x40 |  1   | CN 6 | P Hi | CN 9 | CN A | CN 5 | P Lo | FC 1 |
+    0x50 | CN C | CN 0 | CN 5 | CN D | FC 5 | CN E | CN 7 | FC 4 |
+    0x60 | FC 3 | FC 6 | CN 1 | CN 8 | CN B | FC 2 | CN 4 |  1   |
+    0x70 | CN 3 | FC 7 | FC 0 | CN 2 |  0   |  0   |  0   |  0   |
+*/
+int getIndalaBits4041x(uint8_t fc, uint16_t cn, uint8_t *bits) {
+
+    // Preamble and required values
+    bits[0] = 0x01;
+    bits[2] = 0x01;
+    bits[32] = 0x01;
+    bits[40] = 0x01;
+    bits[55] = 0x01;
+
+    // Facility code
+    bits[57] = ((fc >> 7) & 0x01);  // MSB
+    bits[49] = ((fc >> 6) & 0x01);
+    bits[44] = ((fc >> 5) & 0x01);
+    bits[47] = ((fc >> 4) & 0x01);
+    bits[48] = ((fc >> 3) & 0x01);
+    bits[53] = ((fc >> 2) & 0x01);
+    bits[39] = ((fc >> 1) & 0x01);
+    bits[58] = (fc & 0x01);         // LSB
+
+    // Serial number
+    bits[42] = ((cn >> 15) & 0x01); // MSB H
+    bits[45] = ((cn >> 14) & 0x01);
+    bits[43] = ((cn >> 13) & 0x01);
+    bits[40] = ((cn >> 12) & 0x01);
+    bits[52] = ((cn >> 11) & 0x01);
+    bits[36] = ((cn >> 10) & 0x01);
+    bits[35] = ((cn >> 9) & 0x01);
+    bits[51] = ((cn >> 8) & 0x01);  // LSB H
+    bits[46] = ((cn >> 7) & 0x01);  // MSB L
+    bits[33] = ((cn >> 6) & 0x01);
+    bits[37] = ((cn >> 5) & 0x01);
+    bits[54] = ((cn >> 4) & 0x01);
+    bits[56] = ((cn >> 3) & 0x01);
+    bits[59] = ((cn >> 2) & 0x01);
+    bits[50] = ((cn >> 1) & 0x01);
+    bits[41] = (cn & 0x01);         // LSB L
+
+    // Parity
+    bits[34] = evenparity16((fc << 4) | (cn >> 12));
+    bits[38] = oddparity16(cn & 0x0fff);
+
+    return PM3_SUCCESS;
+}
+
 // redesigned by marshmellow adjusted from existing decode functions
 // indala id decoding
 int detectIndala(uint8_t *dest, size_t *size, uint8_t *invert) {
