@@ -169,7 +169,7 @@ int demodPyramid(bool verbose) {
                   , (checksum == checkCS) ? _GREEN_("ok") : _RED_("fail")
                  );
 
-    PrintAndLogEx(DEBUG, "DEBUG: Pyramid: idx: %d, Len: %d, Printing Demod Buffer:", idx, 128);
+    PrintAndLogEx(DEBUG, "DEBUG: Pyramid: idx: %d, Len: %d, Printing DemodBuffer:", idx, 128);
     if (g_debugMode) {
         printDemodBuff(0, false, false, false);
     }
@@ -430,7 +430,7 @@ int detectPyramid(uint8_t *dest, size_t *size, int *waveStartIdx) {
         return -4; //preamble not found
 
     // wrong size?  (between to preambles)
-    if (*size != 128) return -5;
+    if (*size < 128) return -5;
 
     return (int)startIdx;
 }
