@@ -68,7 +68,7 @@ static uint8_t GetATRTA1(uint8_t *atr, size_t atrlen) {
     return 0x11; // default value is 0x11, corresponding to fmax=5 MHz, Fi=372, Di=1.
 }
 
-int DiArray[] = {
+static int DiArray[] = {
     0,  // b0000 RFU
     1,  // b0001
     2,
@@ -87,7 +87,7 @@ int DiArray[] = {
     0    // b1111 RFU
 };
 
-int FiArray[] = {
+static int FiArray[] = {
     372,    // b0000 Historical note: in ISO/IEC 7816-3:1989, this was assigned to cards with internal clock
     372,    // b0001
     558,    // b0010
@@ -106,7 +106,7 @@ int FiArray[] = {
     0       // b1111 RFU
 };
 
-float FArray[] = {
+static float FArray[] = {
     4,    // b0000 Historical note: in ISO/IEC 7816-3:1989, this was assigned to cards with internal clock
     5,    // b0001
     6,    // b0010
@@ -1167,7 +1167,7 @@ bool smart_select(bool verbose, smart_card_atr_t *atr) {
     SendCommandNG(CMD_SMART_ATR, NULL, 0);
     PacketResponseNG resp;
     if (WaitForResponseTimeout(CMD_SMART_ATR, &resp, 2500) == false) {
-        if (verbose) PrintAndLogEx(WARNING, "smart card select timeouted");
+        if (verbose) PrintAndLogEx(WARNING, "smart card select timeout");
         return false;
     }
 
