@@ -38,8 +38,8 @@ bool fskClocks(uint8_t *fc1, uint8_t *fc2, uint8_t *rf1, int *firstClockEdge);
 #define GRAPH_SAVE 1
 #define GRAPH_RESTORE 0
 
-extern int GraphBuffer[MAX_GRAPH_TRACE_LEN];
-extern size_t GraphTraceLen;
+extern int g_GraphBuffer[MAX_GRAPH_TRACE_LEN];
+extern size_t g_GraphTraceLen;
 
 #ifdef __cplusplus
 }
