@@ -6,7 +6,7 @@
 #include "prng.h"
 
 #define rot(x,k) (((x)<<(k))|((x)>>(32-(k))))
-uint32_t burtle_get_mod(prng_ctx *x) {
+uint32_t burtle_get_mod(prng_ctx_t *x) {
     uint32_t e = x->a - rot(x->b, 21);
     x->a = x->b ^ rot(x->c, 19);
     x->b = x->c + rot(x->d, 6);
@@ -15,7 +15,7 @@ uint32_t burtle_get_mod(prng_ctx *x) {
     return x->d;
 }
 
-void burtle_init_mod(prng_ctx *x, uint32_t seed) {
+void burtle_init_mod(prng_ctx_t *x, uint32_t seed) {
     x->a = 0xf1ea5eed;
     x->b = x->c = x->d = seed;
     for (uint8_t i = 0; i < 42; ++i) {
@@ -23,7 +23,7 @@ void burtle_init_mod(prng_ctx *x, uint32_t seed) {
     }
 }
 
-void burtle_init(prng_ctx *x, uint32_t seed) {
+void burtle_init(prng_ctx_t *x, uint32_t seed) {
     uint32_t i;
     x->a = 0xf1ea5eed, x->b = x->c = x->d = seed;
     for (i = 0; i < 20; ++i) {
