@@ -25,7 +25,7 @@
 
 #include "ui.h"     // PrintAndLog
 
-#define UTIL_BUFFER_SIZE_SPRINT 4097
+#define UTIL_BUFFER_SIZE_SPRINT 8193
 // global client debug variable
 uint8_t g_debugMode = 0;
 // global client disable logging variable
@@ -249,6 +249,22 @@ void print_buffer(const uint8_t *data, const size_t len, int level) {
     print_buffer_ex(data, len, level, 16);
 }
 
+void print_buffer_with_offset(const uint8_t *data, const size_t len, int offset, bool print_header) {
+    if (print_header) {
+        PrintAndLogEx(INFO, " Offset  | Data                                            | Ascii");
+        PrintAndLogEx(INFO, "----------------------------------------------------------------------------");
+    }
+
+    for (uint32_t i = 0; i < len; i += 16) {
+        uint32_t l = len - i;
+        PrintAndLogEx(INFO, "%3d/0x%02X | %s" NOLF, offset + i, offset + i, sprint_hex(&data[i], l > 16 ? 16 : l));
+        if (l < 16)
+            PrintAndLogEx(NORMAL, "%*s" NOLF, 3 * (16 - l), " ");
+        PrintAndLogEx(NORMAL, "| %s", sprint_ascii(&data[i], l > 16 ? 16 : l));
+    }
+}
+
+
 void print_blocks(uint32_t *data, size_t len) {
     PrintAndLogEx(SUCCESS, "Blk | Data ");
     PrintAndLogEx(SUCCESS, "----+------------");
@@ -282,7 +298,7 @@ char *sprint_hex_inrow_spaces(const uint8_t *data, const size_t len, size_t spac
     return buf;
 }
 
-char *sprint_bin_break(const uint8_t *data, const size_t len, const uint8_t breaks) {
+char *sprint_bytebits_bin_break(const uint8_t *data, const size_t len, const uint8_t breaks) {
 
     // make sure we don't go beyond our char array memory
     size_t rowlen = (len > MAX_BIN_BREAK_LENGTH) ? MAX_BIN_BREAK_LENGTH : len;
@@ -297,10 +313,14 @@ char *sprint_bin_break(const uint8_t *data, const size_t len, const uint8_t brea
 
         char c = data[i];
         // manchester wrong bit marker
-        if (c == 7)
+        if (c == 7) {
             c = '.';
-        else
+        } else if (c < 2) {
             c += '0';
+        } else {
+            PrintAndLogEx(ERR, "Invalid data passed to sprint_bytebits_bin_break()");
+            return buf;
+        }
 
         *(tmp++) = c;
 
@@ -353,8 +373,15 @@ void sprint_bin_break_ex(uint8_t *src, size_t srclen, char *dest , uint8_t break
 }
 */
 
+char *sprint_bytebits_bin(const uint8_t *data, const size_t len) {
+    return sprint_bytebits_bin_break(data, len, 0);
+}
+
 char *sprint_bin(const uint8_t *data, const size_t len) {
-    return sprint_bin_break(data, len, 0);
+    size_t binlen = (len * 8 > MAX_BIN_BREAK_LENGTH) ? MAX_BIN_BREAK_LENGTH : len * 8;
+    static uint8_t buf[MAX_BIN_BREAK_LENGTH];
+    bytes_to_bytebits(data, binlen / 8, buf);
+    return sprint_bytebits_bin_break(buf, binlen, 0);
 }
 
 char *sprint_hex_ascii(const uint8_t *data, const size_t len) {
@@ -458,14 +485,15 @@ void num_to_bytebitsLSBF(uint64_t n, size_t len, uint8_t *dest) {
     }
 }
 
-void bytes_to_bytebits(void *src, size_t srclen, void *dest) {
+void bytes_to_bytebits(const void *src, const size_t srclen, void *dest) {
 
     uint8_t *s = (uint8_t *)src;
     uint8_t *d = (uint8_t *)dest;
 
     uint32_t i = srclen * 8;
-    while (srclen--) {
-        uint8_t b = s[srclen];
+    size_t j = srclen;
+    while (j--) {
+        uint8_t b = s[j];
         d[--i] = (b >> 0) & 1;
         d[--i] = (b >> 1) & 1;
         d[--i] = (b >> 2) & 1;
