@@ -62,7 +62,7 @@ uint8_t g_debugMode = 0;
 # define prnt Dbprintf
 #endif
 
-signal_t signalprop = { 255, -255, 0, 0, true };
+static signal_t signalprop = { 255, -255, 0, 0, true };
 signal_t *getSignalProperties(void) {
     return &signalprop;
 }
@@ -253,6 +253,55 @@ size_t removeParity(uint8_t *bits, size_t startIdx, uint8_t pLen, uint8_t pType,
     return bitCnt;
 }
 
+static size_t removeEm410xParity(uint8_t *bits, size_t startIdx, bool isLong, bool *validShort, bool *validShortExtended, bool *validLong) {
+    uint32_t parityWd = 0;
+    size_t bitCnt = 0;
+    bool validColParity = false;
+    bool validRowParity = true;
+    bool validRowParitySkipColP = true;
+    *validShort = false;
+    *validShortExtended = false;
+    *validLong = false;
+    uint8_t bLen = isLong ? 110 : 55;
+    uint16_t parityCol[4] = { 0, 0, 0, 0 };
+    for (int word = 0; word < bLen; word += 5) {
+        for (int bit = 0; bit < 5; bit++) {
+            if (word + bit >= bLen) break;
+            parityWd = (parityWd << 1) | bits[startIdx + word + bit];
+            if ((word <= 50) && (bit < 4))
+                parityCol[bit] = (parityCol[bit] << 1) | bits[startIdx + word + bit];
+            bits[bitCnt++] = (bits[startIdx + word + bit]);
+        }
+        if (word + 5 > bLen) break;
+
+        bitCnt--; // overwrite parity with next data
+        validRowParity &= parityTest(parityWd, 5, 0) != 0;
+        if (word == 50) { // column parity nibble on short EM and on Electra
+            validColParity = parityTest(parityCol[0], 11, 0) != 0;
+            validColParity &= parityTest(parityCol[1], 11, 0) != 0;
+            validColParity &= parityTest(parityCol[2], 11, 0) != 0;
+            validColParity &= parityTest(parityCol[3], 11, 0) != 0;
+        } else {
+            validRowParitySkipColP &= parityTest(parityWd, 5, 0) != 0;
+        }
+        parityWd = 0;
+    }
+    if (!isLong && validRowParitySkipColP && validColParity) {
+        *validShort = true;
+    }
+    if (isLong && validRowParity) {
+        *validLong = true;
+    }
+    if (isLong && validRowParitySkipColP && validColParity) {
+        *validShortExtended = true;
+    }
+    if (*validShort || *validShortExtended || *validLong) {
+        return bitCnt;
+    } else {
+        return 0;
+    }
+}
+
 // by marshmellow
 // takes a array of binary values, length of bits per parity (includes parity bit),
 //   Parity Type (1 for odd; 0 for even; 2 Always 1's; 3 Always 0's), and binary Length (length to run)
@@ -1996,7 +2045,8 @@ int pskRawDemod_ext(uint8_t *dest, size_t *size, int *clock, int *invert, int *s
     uint8_t curPhase = *invert;
     uint8_t fc = 0;
     size_t i = 0, numBits = 0, waveStart = 1, waveEnd, firstFullWave = 0, lastClkBit = 0;
-    uint16_t fullWaveLen = 0, waveLenCnt, avgWaveVal = 0;
+    uint16_t fullWaveLen = 0, waveLenCnt;
+    //uint16_t avgWaveVal = 0;
     uint16_t errCnt = 0, errCnt2 = 0;
 
     *clock = DetectPSKClock(dest, *size, *clock, &firstFullWave, &curPhase, &fc);
@@ -2036,7 +2086,7 @@ int pskRawDemod_ext(uint8_t *dest, size_t *size, int *clock, int *invert, int *s
         if (dest[i] + fc < dest[i + 1] && dest[i + 1] >= dest[i + 2]) {
             if (waveStart == 0) {
                 waveStart = i + 1;
-                avgWaveVal = dest[i + 1];
+                //avgWaveVal = dest[i + 1];
             } else { //waveEnd
                 waveEnd = i + 1;
                 waveLenCnt = waveEnd - waveStart;
@@ -2066,14 +2116,14 @@ int pskRawDemod_ext(uint8_t *dest, size_t *size, int *clock, int *invert, int *s
                 } else if (waveLenCnt < fc - 1) { //wave is smaller than field clock (shouldn't happen often)
                     errCnt2++;
                     if (errCnt2 > 101) return errCnt2;
-                    avgWaveVal += dest[i + 1];
+                    //avgWaveVal += dest[i + 1];
                     continue;
                 }
-                avgWaveVal = 0;
+                //avgWaveVal = 0;
                 waveStart = i + 1;
             }
         }
-        avgWaveVal += dest[i + 1];
+        //avgWaveVal += dest[i + 1];
     }
     *size = numBits;
     return errCnt;
@@ -2122,7 +2172,6 @@ int Em410xDecode(uint8_t *bits, size_t *size, size_t *start_idx, uint32_t *hi, u
     if (bits[1] > 1) return -1;
     if (*size < 64) return -2;
 
-    uint8_t fmtlen;
     *start_idx = 0;
 
     // preamble 0111111111
@@ -2131,32 +2180,29 @@ int Em410xDecode(uint8_t *bits, size_t *size, size_t *start_idx, uint32_t *hi, u
     if (!preambleSearch(bits, preamble, sizeof(preamble), size, start_idx))
         return -4;
 
-    // (iceman) if the preamble doesn't find two occuriences, this identification fails.
-    fmtlen = (*size == 128) ? 22 : 10;
+    bool validShort = false;
+    bool validShortExtended = false;
+    bool validLong = false;
+    *size = removeEm410xParity(bits, *start_idx + sizeof(preamble), *size == 128, &validShort, &validShortExtended, &validLong);
 
-    //skip last 4bit parity row for simplicity
-    *size = removeParity(bits, *start_idx + sizeof(preamble), 5, 0, fmtlen * 5);
-
-    switch (*size) {
-        case 40: {
-            // std em410x format
-            *hi = 0;
-            *lo = ((uint64_t)(bytebits_to_byte(bits, 8)) << 32) | (bytebits_to_byte(bits + 8, 32));
-            break;
-        }
-        case 88:  {
-            // long em format
-            *hi = (bytebits_to_byte(bits, 24));
-            *lo = ((uint64_t)(bytebits_to_byte(bits + 24, 32)) << 32) | (bytebits_to_byte(bits + 24 + 32, 32));
-            break;
-        }
-        default:
-            return -6;
+    if (validShort) {
+        // std em410x format
+        *hi = 0;
+        *lo = ((uint64_t)(bytebits_to_byte(bits, 8)) << 32) | (bytebits_to_byte(bits + 8, 32));
+        // 1 = Short
+        return 1;
     }
-    return 1;
+    if (validShortExtended || validLong) {
+        // store in long em format
+        *hi = (bytebits_to_byte(bits, 24));
+        *lo = ((uint64_t)(bytebits_to_byte(bits + 24, 32)) << 32) | (bytebits_to_byte(bits + 24 + 32, 32));
+        // 2 = Long
+        // 4 = ShortExtended
+        return ((int)validShortExtended << 2) + ((int)validLong << 1);
+    }
+    return -6;
 }
 
-
 // loop to get raw HID waveform then FSK demodulate the TAG ID from it
 int HIDdemodFSK(uint8_t *dest, size_t *size, uint32_t *hi2, uint32_t *hi, uint32_t *lo, int *waveStartIdx) {
     //make sure buffer has data
