@@ -13,14 +13,32 @@
 
 #include "common.h"
 
-extern const uint8_t OddByteParity[256];
+extern const uint8_t g_OddByteParity[256];
 
 static inline uint8_t oddparity8(const uint8_t x) {
-    return OddByteParity[x];
+    return g_OddByteParity[x];
 }
 
 static inline uint8_t evenparity8(const uint8_t x) {
-    return !OddByteParity[x];
+    return !g_OddByteParity[x];
+}
+
+static inline uint8_t evenparity16(uint16_t x) {
+#if !defined __GNUC__
+    x ^= x >> 8;
+    return evenparity8(x);
+#else
+    return (__builtin_parity(x) & 0xFF);
+#endif
+}
+
+static inline uint8_t oddparity16(uint16_t x) {
+#if !defined __GNUC__
+    x ^= x >> 8;
+    return oddparity8(x);
+#else
+    return !__builtin_parity(x);
+#endif
 }
 
 static inline uint8_t evenparity32(uint32_t x) {
