@@ -31,6 +31,8 @@ Ultralight C
     1A = Step1 Authenticate
     AF = Step2 Authenticate
 
+NTAG i2c 2K
+    C2 = SECTOR_SELECT
 
 ISO14443B
     05 = REQB
@@ -190,6 +192,11 @@ ISO 7816-4 Basic interindustry commands. For command APDU's.
 #define MIFARE_ULNANO_WRITESIG      0xA9
 #define MIFARE_ULNANO_LOCKSIG       0xAC
 
+// NTAG i2k 2K  uses sector 0, and sector 1 to have access to
+// block 0x00-0xFF.
+#define NTAG_I2C_SELECT_SECTOR      0xC2
+#define NTAG_I2C_FASTWRITE          0xA6
+
 // mifare 4bit card answers
 #define CARD_ACK      0x0A  // 1010 - ACK
 #define CARD_NACK_IV  0x00  // 0000 - NACK, invalid argument (invalid page address)
@@ -424,6 +431,7 @@ ISO 7816-4 Basic interindustry commands. For command APDU's.
 #define MFDES_INIT_KEY_SETTINGS         0x56
 #define MFDES_FINALIZE_KEY_SETTINGS     0x57
 #define MFDES_SELECT_APPLICATION        0x5A
+#define MFDES_CHANGE_CONFIGURATION      0x5C
 #define MFDES_CHANGE_FILE_SETTINGS      0x5F
 #define MFDES_GET_VERSION               0x60
 #define MFDES_GET_ISOFILE_IDS           0x61
@@ -434,8 +442,13 @@ ISO 7816-4 Basic interindustry commands. For command APDU's.
 #define MFDES_GET_FREE_MEMORY           0x6E
 #define MFDES_GET_DF_NAMES              0x6D
 #define MFDES_GET_FILE_IDS              0x6F
+#define MFDES_WRITE_RECORD2             0x8B
+#define MFDES_WRITE_DATA2               0x8D
 #define MFDES_ABORT_TRANSACTION         0xA7
+#define MFDES_READ_RECORDS2             0xAB
+#define MFDES_READ_DATA2                0xAD
 #define MFDES_ADDITIONAL_FRAME          0xAF
+#define MFDES_UPDATE_RECORD2            0xBA
 #define MFDES_READ_RECORDS              0xBB
 #define MFDES_READ_DATA                 0xBD
 #define MFDES_CREATE_CYCLIC_RECORD_FILE 0xC0
@@ -451,6 +464,7 @@ ISO 7816-4 Basic interindustry commands. For command APDU's.
 #define MFDES_CREATE_STD_DATA_FILE      0xCD
 #define MFDES_CREATE_TRANS_MAC_FILE     0xCE
 #define MFDES_DELETE_APPLICATION        0xDA
+#define MFDES_UPDATE_RECORD             0xDB
 #define MFDES_DEBIT                     0xDC
 #define MFDES_DELETE_FILE               0xDF
 #define MFDES_CLEAR_RECORD_FILE         0xEB
@@ -459,6 +473,7 @@ ISO 7816-4 Basic interindustry commands. For command APDU's.
 #define MFDES_GET_FILE_SETTINGS         0xF5
 #define MFDES_FORMAT_PICC               0xFC
 #define MFDES_VERIFY_PC                 0xFD
+#define MFDES_NATIVE_ISO7816_WRAP_CLA   0x90
 
 // MIFARE DESFire status & error codes:
 #define MFDES_S_OPERATION_OK            0x00
