@@ -124,9 +124,7 @@ static int is_kmiddle_badguess(uint64_t z, struct Tklower *Tk, int max, int aR0)
 // function to test if a partial key is valid
 static int testkey(uint64_t *out, uint64_t uid, uint64_t pkey, uint64_t nR, uint64_t aR) {
     uint64_t kupper;
-    uint64_t key;
     Hitag_State hstate;
-    uint64_t b;
     uint32_t revaR;
     uint32_t normaR;
 
@@ -136,9 +134,9 @@ static int testkey(uint64_t *out, uint64_t uid, uint64_t pkey, uint64_t nR, uint
 
     // search for remaining 14 bits
     for (kupper = 0; kupper < 0x3fff; kupper++) {
-        key = (kupper << 34) | pkey;
+        uint64_t key = (kupper << 34) | pkey;
         hitag2_init(&hstate, key, uid, nR);
-        b = hitag2_nstep(&hstate, 32);
+        uint64_t b = hitag2_nstep(&hstate, 32);
         if ((normaR ^ b) == 0xffffffff) {
             *out = key;
             return 1;
@@ -177,13 +175,11 @@ static void *crack(void *d) {
     struct nRaR *TnRaR;
     unsigned int numnrar;
 
-    Hitag_State hstate;
     int i, j;
 
     uint64_t klower, kmiddle, klowery;
     uint64_t y, b, z, bit;
     uint64_t ytmp;
-    unsigned int count;
     uint64_t foundkey, revkey;
     int ret;
     unsigned int found;
@@ -210,7 +206,7 @@ static void *crack(void *d) {
     for (klower = data->klowerstart; klower < (data->klowerstart + data->klowerrange); klower++) {
         printf("trying klower = 0x%05"PRIx64"\n", klower);
         // build table
-        count = 0;
+        unsigned int count = 0;
         for (y = 0; y < 0x40000; y++) {
             // create klowery
             klowery = (y << 16) | klower;
@@ -220,17 +216,15 @@ static void *crack(void *d) {
                 // store klowery
                 Tk[count].klowery = klowery;
                 // build the initial prng state
-                hstate.shiftreg = (klower << 32) | uid;
-                // zero the lfsr so only 0s are inserted
-                hstate.lfsr = 0;
+                uint64_t shiftreg = (klower << 32) | uid;
                 // insert y into shiftreg and extract keystream, reversed order
                 b = 0;
                 ytmp = y;
                 for (j = 0; j < 2; j++) {
-                    hstate.shiftreg = hstate.shiftreg | ((ytmp & 0xffff) << 48);
+                    shiftreg = shiftreg | ((ytmp & 0xffff) << 48);
                     for (i = 0; i < 16; i++) {
-                        hstate.shiftreg = hstate.shiftreg >> 1;
-                        bit = hitag2_crypt(hstate.shiftreg);
+                        shiftreg = shiftreg >> 1;
+                        bit = hitag2_crypt(shiftreg);
                         b = (b >> 1) | (bit << 31);
                     }
                     ytmp = ytmp >> 16;
@@ -242,8 +236,8 @@ static void *crack(void *d) {
                 // get and store inverse of next bit from prng
                 // don't need to worry about shifting in the new bit because
                 // it doesn't affect the filter function anyway
-                hstate.shiftreg = hstate.shiftreg >> 1;
-                Tk[count].notb32 = hitag2_crypt(hstate.shiftreg) ^ 0x1;
+                shiftreg = shiftreg >> 1;
+                Tk[count].notb32 = hitag2_crypt(shiftreg) ^ 0x1;
 
                 // increase count
                 count++;
